@@ -1,5 +1,466 @@
 import pgmagick
 
+_EXIF_TAGS = [
+    "ImageWidth",
+    "ImageLength",
+    "BitsPerSample",
+    "Compression",
+    "PhotometricInterpretation",
+    "ImageDescription",
+    "Make",
+    "Model",
+    "StripOffsets",
+    "Orientation",
+    "SamplesPerPixel",
+    "RowsPerStrip",
+    "StripByteCounts",
+    "XResolution",
+    "YResolution",
+    "PlanarConfiguration",
+    "ResolutionUnit",
+    "TransferFunction",
+    "CreatorTool",
+    "ModifyDate",
+    "Artist",
+    "WhitePoint",
+    "PrimaryChromaticities",
+    "JPEGInterchangeFormat",
+    "JPEGInterchangeFormatLength",
+    "YCbCrCoefficients",
+    "YCbCrSubSampling",
+    "YCbCrPositioning",
+    "ReferenceBlackWhite",
+    "Copyright",
+    "ExposureTime",
+    "FNumber",
+    "ExifIFDPointer",
+    "ExposureProgram",
+    "SpectralSensitivity",
+    "GPSInfoIFDPointer",
+    "ISOSpeedRatings",
+    "OECF",
+    "ExifVersion",
+    "DateTimeOriginal",
+    "MetadataDate",
+    "ComponentsConfiguration",
+    "CompressedBitsPerPixel",
+    "ShutterSpeedValue",
+    "ApertureValue",
+    "BrightnessValue",
+    "ExposureBiasValue",
+    "MaxApertureValue",
+    "SubjectDistance",
+    "MeteringMode",
+    "LightSource",
+    "Flash",
+    "FocalLength",
+    "SubjectArea",
+    "MakerNote",
+    "UserComment",
+    "SubSecTime",
+    "SubSecTimeOriginal",
+    "SubSecTimeDegitized",
+    "FlashpixVersion",
+    "ColorSpace",
+    "PixelXDimension",
+    "PixelYDimension",
+    "RelatedSoundFile",
+    "InteroperabilityIFDPointer",
+    "FlashEnergy",
+    "SpatialFrequencyResponse",
+    "FocalPlaneXResolution",
+    "FocalPlaneYResolution",
+    "FocalPlaneResolutionUnit",
+    "SubjectLocation",
+    "ExposureIndex",
+    "SensingMethod",
+    "FileSource",
+    "SceneType",
+    "CFAPattern",
+    "CustomRendered",
+    "ExposureMode",
+    "WhiteBalance",
+    "DigitalZoomRatio",
+    "FocalLengthIn35mmFilm",
+    "SceneCaptureType",
+    "GainControl",
+    "Contrast",
+    "Saturation",
+    "Sharpness",
+    "DeviceSettingDescription",
+    "SubjectDistanceRange",
+    "0xa420",
+    "0xa500",
+    "DNGVersion",
+    "DNGBackwardVersion",
+    "DNGUniqueCameraModel",
+    "DNGLocalizedCameraModel",
+    "DNGCFAPlaneColor",
+    "DNGCFALayout",
+    "DNGLinearizationTable",
+    "DNGBlackLevelRepeatDim",
+    "DNGBlackLevel",
+    "DNGBlackLevelDeltaH",
+    "DNGBlackLevelDeltaV",
+    "DNGWhiteLevel",
+    "DNGDefaultscale",
+    "DNGDefaultCropOrigin",
+    "DNGDefaultCropSize",
+    "DNGColorMatrix1",
+    "DNGColorMatrix2",
+    "DNGCameraCalibration1",
+    "DNGCameraCalibration2",
+    "DNGReductionMatrix1",
+    "DNGReductionMatrix2",
+    "DNGAnalogBalance",
+    "DNGAsShotNeutral",
+    "DNGAsShotWhiteXY",
+    "DNGBaselineExposure",
+    "DNGBaselineNoise",
+    "DNGBaselineSharpness",
+    "DNGBayerGreenSplit",
+    "DNGLinearResponseLimit",
+    "DNGCameraSerialNumber",
+    "DNGLensInfo",
+    "DNGChromaBlurRadius",
+    "DNGAntiAliasStrength",
+    "DNGShadowScale",
+    "DNGPrivateData",
+    "DNGMakerNoteSafety",
+    "DNGCalibrationIlluminant1",
+    "DNGCalibrationIlluminant2",
+    "DNGBestQualityScale",
+    "DNGRawDataUniqueID",
+    "DNGOriginalRawFileName",
+    "DNGOriginalRawFileData",
+    "DNGActiveArea",
+    "DNGMaskedArea",
+    "DNGAsShotICCProfile",
+    "DNGAsShotPreProfileMatrix",
+    "DNGCurrentICCProfile",
+    "DNGCurrentPreProfileMatrix",
+    "GPSVersionID",
+    "GPSLatitudeRef",
+    "GPSLatitude",
+    "GPSLongitudeRef",
+    "GPSLongitude",
+    "GPSAltitudeRef",
+    "GPSAltitude",
+    "GPSTimeStamp",
+    "GPSSatellites",
+    "GPSStatus",
+    "GPSMessureMode",
+    "GPSDOP",
+    "GPSSpeedRef",
+    "GPSSpeed",
+    "GPSTrackRef",
+    "GPSTrack",
+    "GPSImgDirectionRef",
+    "GPSImgDirection",
+    "GPSMapDatum",
+    "GPSDestLatitudeRef",
+    "GPSDestLatitude",
+    "GPSDestLongitudeRef",
+    "GPSDestLongitude",
+    "GPSDestBearingRef",
+    "GPSDestBearing",
+    "GPSDestDistanceRef",
+    "GPSDestDistance",
+    "GPSProcessingMethod",
+    "GPSAreaInformation",
+    "GPSDateStamp",
+    "GPSDifferential",
+    "InteroperabilityIndex",
+    "CRSRawFileName",
+    "CRSVersion",
+    "CRSWhiteBalance",
+    "CRSTemperature",
+    "CRSTint",
+    "CRSShadowTint",
+    "CRSExposure",
+    "CRSShadows",
+    "CRSBrightness",
+    "CRSContrast",
+    "CRSSaturation",
+    "CRSRedSaturation",
+    "CRSGreenSaturation",
+    "CRSBlueSaturation",
+    "CRSSharpness",
+    "CRSLuminanceSmoothing",
+    "CRSRedHue",
+    "CRSGreenHue",
+    "CRSBlueHue",
+    "CRSColorNoiseReduction",
+    "CRSChromaticAberrationR",
+    "CRSChromaticAberrationB",
+    "CRSVignetteAmount",
+    "CRSLens",
+    "CRSSerialNumber",
+    "CRSAutoBrightness",
+    "CRSAutoShadows",
+    "CRSAutoContrast",
+    "CRSAutoExposure",
+    "OLSpecialMode",
+    "OLJpegQuality",
+    "OLMacro",
+    "OLDigitalZoom",
+    "OLSoftwareRelease",
+    "OLpictInfo",
+    "OLCameraID",
+    "OLDataDump",
+    "OLFlashMode",
+    "OLExposureBias",
+    "OLFocusMode",
+    "OLFocusDistance",
+    "OLZoom",
+    "OLMacroFocus",
+    "OLSharpness",
+    "OLColourMatrix",
+    "OLBlackLevel",
+    "OLWhiteBalance",
+    "OLRedBias",
+    "OLBlueBias",
+    "OLSerialNumber",
+    "OLFlashBias",
+    "OLContrast",
+    "OLSharpnessFactor",
+    "OLColourControl",
+    "OLValidBits",
+    "OLCoringFilter",
+    "OLImageWidth",
+    "OLImageHeight",
+    "OLCompressionRatio",
+    "PXExposureTime",
+    "PXFNumber",
+    "PXISOSpeed",
+    "PXExposureBias",
+    "PXWhiteBalance",
+    "PXLensID",
+    "PXImageTone",
+    "EXThumbInfo",
+    "EXThumbSize",
+    "EXThumbOffset",
+    "EXQualityMode",
+    "EXImageSize",
+    "EXISOSensitivity",
+    "EXWhiteBalance",
+    "EXFocalLength",
+    "EXSaturation",
+    "EXContrast",
+    "EXSharpness",
+    "EXPIM",
+    "EXThumbnail",
+    "EXWBBias",
+    "EXFlash",
+    "EXObjectDistance",
+    "EXFlashDistance",
+    "EXRecordMode",
+    "EXSelfTimer",
+    "EXQuality",
+    "EXFocusMode",
+    "EXTimeZone",
+    "EXBestshotMode",
+    "EXCCDSensitivity",
+    "EXColorMode",
+    "EXColorEnhance",
+    "EXFilter",
+    "PXOCaptureMode",
+    "PXOQualityLevel",
+    "PXOFocusMode",
+    "PXOFlashMode",
+    "PXOWhiteBalance",
+    "PXODigitalZoom",
+    "PXOSharpness",
+    "PXOContrast",
+    "PXOSaturation",
+    "PXOISOSpeed",
+    "PXOColorMode",
+    "PXOTimeZone",
+    "PXODaylightSavings",
+    "NKISOSetting",
+    "NKColorMode",
+    "NKQuality",
+    "NKWhitebalance",
+    "NKSharpness",
+    "NKFocusMode",
+    "NKFlashSetting",
+    "NKFlashMode",
+    "NKWhiteBalanceOffset",
+    "NKISOselection",
+    "NKThumbnailIFDOffset",
+    "NKImageAdjustment",
+    "NKContrastSetting",
+    "NKAdapter",
+    "NKLensSetting",
+    "NKLensInfo",
+    "NKManualFocusDistance",
+    "NKDigitalZoom",
+    "NKAFFocusPoint",
+    "NKShutterMode",
+    "NKColorSpace",
+    "NKColorOffset",
+    "NKNoiseReduction",
+    "NKLendID",
+    "NKShotCount",
+    "NKFinishSetting",
+    "NKDigitalImgProg",
+    "NKEQuality",
+    "NKEColorMode",
+    "NKEImageAdjustment",
+    "NKECCDSensitivity",
+    "NKEWhiteBalance",
+    "NKEFocus",
+    "NKEDigitalZoom",
+    "NKEConverter",
+    "MLTMakerNoteVersion",
+    "MLTCameraSettingsOld",
+    "MLTExposureMode",
+    "MLTFlashMode",
+    "MLTWhiteBalance",
+    "MLTImageSize",
+    "MLTImageQuality",
+    "MLTDriveMode",
+    "MLTMeteringMode",
+    "MLTFilmSpeed",
+    "MLTShutterSpeed",
+    "MLTAperture",
+    "MLTMacroMode",
+    "MLTDigitalZoom",
+    "MLTExposureCompensation",
+    "MLTBracketStep",
+    "MLTunknown16",
+    "MLTIntervalLength",
+    "MLTIntervalNumber",
+    "MLTFocalLength",
+    "MLTFocusDistance",
+    "MLTFlashFired",
+    "MLTDate",
+    "MLTTime",
+    "MLTMaxAperture",
+    "MLTFileNumberMemory",
+    "MLTLastFileNumber",
+    "MLTWhiteBalanceRed",
+    "MLTWhiteBalanceGreen",
+    "MLTWhiteBalanceBlue",
+    "MLTSaturation",
+    "MLTContrast",
+    "MLTSharpness",
+    "MLTSubjectProgram",
+    "MLTFlashCompensation",
+    "MLTISOSetting",
+    "MLTCameraModel",
+    "MLTIntervalMode",
+    "MLTFolderName",
+    "MLTColorMode",
+    "MLTColorFilter",
+    "MLTBWFilter",
+    "MLTInternalFlash",
+    "MLTBrightnessValue",
+    "MLTSpotFocusPointX",
+    "MLTSpotFocusPointY",
+    "MLTWideFocusZone",
+    "MLTFocusMode",
+    "MLTFocusArea",
+    "MLTDECPosition",
+    "MLTComppressImageSize",
+    "MLTThumbnail",
+    "MLTThumbnailOffset",
+    "MLTThumbnailLength",
+    "MLTLensID",
+    "MLTPIMInformation",
+    "MLTCameraSettings",
+    "SGSerialID",
+    "SGDriveMode",
+    "SGImageSize",
+    "SGAFMode",
+    "SGFocusMode",
+    "SGWhiteBalance",
+    "SGExposureMode",
+    "SGMeteringMode",
+    "SGFocalLength",
+    "SGColorSpace",
+    "SGExposure",
+    "SGContrast",
+    "SGShadow",
+    "SGHighlight",
+    "SGSaturation",
+    "SGSharpness",
+    "SGX3FillLight",
+    "SGColorCoordination",
+    "SGCustomSettingMode",
+    "SGJpegQuality",
+    "SGFirmware",
+    "SGSoftware",
+    "SGAutoBlacket",
+    "CNMacroMode",
+    "CNSelfTimer",
+    "CNFlash",
+    "CNDriveMode",
+    "CNFocusMode",
+    "CNImageSize",
+    "CNImageSelect",
+    "CNDigitalZoom",
+    "CNContrast",
+    "CNSaturation",
+    "CNSharpness",
+    "CNISOSensitive",
+    "CNMeteringMode",
+    "CNFocusType",
+    "CNAFPoint",
+    "CNExposurePorgram",
+    "CNLensID",
+    "CNLensMaximum",
+    "CNLensMinimum",
+    "CNLensUnit",
+    "CNFlashDetailed",
+    "CNFocusSetting",
+    "CNImageStabilization",
+    "CNImageEffect",
+    "CNHueBias",
+    "CNWhitebalance",
+    "CNImageNumber",
+    "CNAFPointUsed",
+    "CNFlashBias",
+    "CNAperture",
+    "CNExposure",
+    "CNNDFilter",
+    "CNImageType",
+    "CNFirmware",
+    "CNUser",
+    "CNSerial",
+    "CNNoiseReduction",
+    "CNButtunFunction",
+    "CNMirrorLockUp",
+    "CNShutterStep",
+    "CNAFSupliment",
+    "CNApexPriority",
+    "CNAEFunction",
+    "CNShutterSynchro",
+    "CNAFStopButton",
+    "CNFlashMemLimit",
+    "CNMenuPosition",
+    "CNSETFunction",
+    "CNSensorCleaning",
+    "CNColorTemp",
+    "CNColorSpace",
+    "FJVersion",
+    "FJQuality",
+    "FJSharpness",
+    "FJWhiteBalance",
+    "FJColor",
+    "FJFlashMode",
+    "FJFlashStrength",
+    "FJMacro",
+    "FJFocusMode",
+    "FJSlowSync",
+    "FJPictureMode",
+    "FJContBlacket",
+    "FJBlurWarning",
+    "FJFocusWarning",
+    "FJAEWarning",
+    "KCMode",
+]
+
 
 def _convert_colorobj(input_obj):
     if isinstance(input_obj, (list, tuple)):
@@ -255,6 +716,17 @@ class Image(object):
         else:
             return self.img.fontPointsize()
 
+    # extra
+    def get_exif_info(self):
+        """return exif-tag dict
+        """
+        _dict = {}
+        for tag in _EXIF_TAGS:
+            ret = self.img.attribute("EXIF:%s" % tag)
+            if ret and ret != 'unknown':
+                _dict[tag] = ret
+        return _dict
+
 
 class Draw(object):
 
@@ -477,11 +949,9 @@ class Draw(object):
         :param linejoin: 'undefined', 'miter', 'round', 'bevel'
         :type linejoin: str
         """
-        print linejoin.title()
-        _linejoin = getattr(pgmagick.LineJoin, "%sJoin" % linejoin.title())
-        print _linejoin
-        drawlinejoin = pgmagick.DrawableStrokeLineJoin(_linejoin)
-        self.drawer.append(drawlinejoin)
+        linejoin = getattr(pgmagick.LineJoin, "%sJoin" % linejoin.title())
+        linejoin = pgmagick.DrawableStrokeLineJoin(linejoin)
+        self.drawer.append(linejoin)
 
     def stroke_opacity(self, opacity):
         self.drawer.append(pgmagick.DrawableStrokeOpacity(float(opacity)))
